-   [ ] Closes #xxxx (Replace xxxx with the GitHub issue number)
-   [ ] Tests added and passed if fixing a bug or adding a new feature
-   [ ] All code checks passed
-   [ ] Added type annotations to new arguments/methods/functions
-   [ ] Added an entry in the latest `docs/release_notes/index.md` file if fixing a bug or adding a new feature
-   [ ] If the changes are patches for a version, I have added the `on-merge: backport to x.x.x` label
